####################################################################################
#### Classifying use of Green-Brown by Arctic small mammals 
#### 3 species - MIOE, MYRU, SOCI across 3 time periods (1990, 2005, 2021)
#### LDA classification of sources/consumers + proportional analysis
####################################################################################

rm(list=ls(all=TRUE))

library(MASS)
library(car)
library(ellipse)
library(ggplot2)
library(gridExtra)
library(ggpubr)
library(plyr)
library(reshape2)
library(fBasics)
library(nortest)
library(stringr)
library(tidyr)
library(broom)
library(tidyverse)
library(dplyr)

setwd()

# load all AAess Data
# sources, consumers, Larsen+Manlick,d13c, d15N 
data <- read.csv("Appendix_S1.csv", strip.white = T, header = T, na.strings = "-")

# Isolate AAess
data.ess<- data %>% 
  dplyr::select(SampleID, group1, group2, species_code, year, site, data, lab, suess_corr, Ile13C, Leu13C, Lys13C, Phe13C, Thr13C, Val13C) %>%
  dplyr::rename("ID"="SampleID", "species" = "species_code",  "Ile" = "Ile13C", "Leu" = "Leu13C", "Lys" = "Lys13C", "Phe" = "Phe13C", "Thr" = "Thr13C", "Val" = "Val13C")

data.ess$ID <- as.character(data.ess$ID)

#Suess correction
data.ess$Ile <- data.ess$Ile-data.ess$suess_corr
data.ess$Leu <- data.ess$Leu-data.ess$suess_corr
data.ess$Lys <- data.ess$Lys-data.ess$suess_corr
data.ess$Phe <- data.ess$Phe-data.ess$suess_corr
data.ess$Thr <- data.ess$Thr-data.ess$suess_corr
data.ess$Val <- data.ess$Val-data.ess$suess_corr

###########################################################################################################
###########################################################################################################
### LDA assignment, Consumers -> Bacteria, Fungi, Plant sources                                        ####
###########################################################################################################
###########################################################################################################

###----------------------------------------------------####
### LDA PRODUCERS -> Bacteria, Fungi, Plant sources    ####
###----------------------------------------------------####

#subset 'sources'by site -> Boreal bact/fungi/plant
data.source <- data.ess %>% filter(site== "Boreal", group2 == "source")

# subset consumers by species
data.consumer <- data.ess %>% filter(site =="Boreal",  group2=="consumer")
data.consumer.mioe <- data.consumer %>% dplyr::filter(species == "MIOE")
data.consumer.myru <- data.consumer %>% dplyr::filter(species == "MYRU")
data.consumer.soci <- data.consumer %>% dplyr::filter(species == "SOCI")

## Calculating an error rate for our LDA model - using producers
data.lda <- lda(group1 ~ Ile + Leu + Lys + Phe + Thr + Val, data = data.source, CV = TRUE)

# create a table which compares the classification of the LDA model to the actual spp
class.prod <- table(data.source$group1, data.lda$class)
class.prod

# total percent of samples correctly classified is the sum of the diagonal of this table
sum(diag(prop.table(class.prod))) #94.4% accuracy overall

# what % of each species is being correctly classified
diag(prop.table(class.prod, 1)) #bac = 100%, fun = 100%, plant = 85.7%

# create a training lda function from the source data - we will use this to classify the coral hosts
data.train <- lda(group1 ~ Ile + Leu + Lys + Phe + Thr + Val , data = data.source)

#examine coefficients of the discriminants to determine AAs contributing to groups separation
data.train$scaling
data.train #get proportions of trace explained

###----------------------------------------------------####
### PLOT1 -> Bacteria, Fungi, Plant sources             ####
###----------------------------------------------------####

# create a dataframe with these LDA coordinates
datPred <- data.frame(ID = data.source$ID,
                      Data = data.source$data,
                      Site= data.source$site,
                      Sample = as.factor(data.source$group1),
                      Group=data.source$group2, 
                      predict(data.train)$x,
                      predict(data.train)$class) #create data.frame

datPred <- datPred %>%  dplyr::rename("class" = "predict.data.train..class") 

#function for source ellipses
source_ell <- data.frame() 
for(g in levels(datPred$Sample)){ 
  source_ell <- rbind(source_ell, cbind(as.data.frame(with(datPred[datPred$Sample==g,], 
                                                     ellipse(cor(LD1, LD2), 
                                                             scale=c(sd(LD1),
                                                                     sd(LD2)), 
                                                             centre=c(mean(LD1), 
                                                                      mean(LD2))))),
                                                                        group=g)) } 

#plot sources confidence ellipses
plot1 = ggplot(datPred, aes(x=LD1, y=LD2))

plot1 + geom_point(aes(colour = Sample), size =4, stroke=2, alpha=0.9)+
  geom_path(data=source_ell,aes(x=x,y=y,colour=group),size=1,linetype=2) +
  theme(legend.title = element_blank()) + theme_classic() +
  labs(x="Linear Discriminant 1", y="Linear Discriminant 2") +
  theme(axis.text=element_text(size=18, color='black'),axis.title=element_text(size=20)) +
  theme(axis.title.y = element_text(vjust=2.5)) + theme(axis.title.x = element_text(vjust=-2))+
  #geom_text(label = rownames(datPred)) +
  theme(legend.position="top") + theme(plot.margin=unit(c(.5,.5,.5,.5),"cm")) +
  scale_colour_manual(values = c("#805D3A", "#C69F78", "#92D050"))

##############################################################
## MIOE ## ---------------------------------------------- ####
##############################################################

# predict consumers based on ess
consumer.pred.mioe <- predict(data.train, data.consumer.mioe)

# creat df of consumer LD coords
datPred2.mioe <- data.frame(ID = data.consumer.mioe$ID,
                       Data = data.consumer.mioe$data,
                       Site= data.consumer.mioe$site,
                       Sample = as.factor(data.consumer.mioe$group1),
                       Group=data.consumer.mioe$group2,
                       consumer.pred.mioe$x,
                       consumer.pred.mioe$class)

datPred2.mioe <- datPred2.mioe %>%  dplyr::rename("class" = "consumer.pred.mioe.class") 

#write.csv(datPred2.mioe, "MIOE_LDA.csv")

###----------------------------------------------------####
### MIOE -> PLOT ---------------------------------     ####
###----------------------------------------------------####

####--------------------------------------------#####
#### perManova -> test differences bn time periods
####--------------------------------------------#####

library(vegan)

#test time periods - LD coords
mioe.perm <- datPred2.mioe %>% select(LD1, LD2)
time<-datPred2.mioe$Sample
adonis2(mioe.perm ~ time, method="euclidean",perm=9999) # p < 0.5*

###################################################################################################

MIOE_LDA = rbind(datPred, datPred2.mioe) #bind producer and consumer data

## plot
plot2 = ggplot(MIOE_LDA, aes(x=LD1, y=LD2))

a=plot2 + geom_point(aes(colour = Sample, size= Group, alpha = Group), stroke=2)+
  geom_path(data=source_ell,aes(x=x,y=y,colour=group),size=.75,linetype=2, alpha=.75) +
  #geom_path(data=consumer_ell.mioe,aes(x=x, y=y,colour=group),size=1,linetype=2) +
  theme(legend.title = element_blank()) + theme_classic() + 
  labs(x="Linear Discriminant 1 (81.2%)", y="Linear Discriminant 2 (18.8%)") +
  theme(axis.text=element_text(size=14, color='black'),axis.title=element_text(size=14)) +
  theme(axis.title.y = element_text(vjust=2.5)) + theme(axis.title.x = element_text(vjust=-2))+
  #geom_text(label = rownames(MIOE_LDA))+
  theme(plot.margin=unit(c(.5,.5,.5,.5),"cm"))+
  theme(legend.key.size = unit(1.5, 'lines')) +
  scale_color_manual(values = c("#805D3A", "#C69F78", "#92D050", "#0077BB", "#DC5665"))+
  scale_alpha_manual(values = c(.8, .5)) + scale_size_manual(values = c(3, 2)) + 
  theme(legend.position="none") #+geom_text(x=-5, y=-4, label="p ≤ 0.01**", size=3.5, check_overlap = T)
  
##############################################################
## MYRU ## ---------------------------------------------- ####
##############################################################

# predict consumers based on ess
consumer.pred.myru <- predict(data.train, data.consumer.myru)

# creat df of consumer LD coords
datPred2.myru <- data.frame(ID = data.consumer.myru$ID,
                            Data = data.consumer.myru$data,
                            Site= data.consumer.myru$site,
                            Sample = as.factor(data.consumer.myru$group1),
                            Group=data.consumer.myru$group2,
                            consumer.pred.myru$x,
                            consumer.pred.myru$class)

datPred2.myru <- datPred2.myru %>%  dplyr::rename("class" = "consumer.pred.myru.class") 

#write.csv(datPred2.myru, "MYRU_LDA.csv")

###----------------------------------------------------####
### myru -> PLOT ---------------------------------     ####
###----------------------------------------------------####

####--------------------------------------------#####
#### perManova -> test differences bn time periods
####--------------------------------------------#####

#test time periods - LD coords
myru.perm <- datPred2.myru %>% select(LD1, LD2)
time<-datPred2.myru$Sample
adonis2(myru.perm ~ time, method="euclidean",perm=9999) # p < 0.001***

#########################################################################################

MYRU_LDA = rbind(datPred, datPred2.myru) #bind producer and consumer data

## plot
plot3 = ggplot(MYRU_LDA, aes(x=LD1, y=LD2))

b=plot3 + geom_point(aes(colour = Sample, size= Group, alpha = Group), stroke=2)+
  geom_path(data=source_ell,aes(x=x,y=y,colour=group),size=.75,linetype=2, alpha=.75) +
  #geom_path(data=consumer_ell.myru,aes(x=x, y=y,colour=group),size=1,linetype=2) +
  theme(legend.title = element_blank()) + theme_classic() + 
  labs(x="Linear Discriminant 1 (81.2%)", y="Linear Discriminant 2 (18.8%)") +
  theme(axis.text=element_text(size=14, color='black'),axis.title=element_text(size=14)) +
  theme(axis.title.y = element_blank()) + theme(axis.title.x = element_text(vjust=-2))+
  #geom_text(label = rownames(MYRU_LDA)) +
  theme(plot.margin=unit(c(.5,.5,.5,.5),"cm"))+
  theme(legend.key.size = unit(1.5, 'lines')) +
  scale_color_manual(values = c("#805D3A", "#C69F78", "#92D050", "#0077BB", "#DC5665"))+
  scale_alpha_manual(values = c(.8, .5)) + scale_size_manual(values = c(3, 2)) +  guides(shape = FALSE) +
  theme(legend.position="none") #+geom_text(x=-5, y=-4, label="p ≤ 0.001***", size=3.5, check_overlap = T)


##############################################################
## SOCI ## ---------------------------------------------- ####
##############################################################

# predict consumers based on ess
consumer.pred.soci <- predict(data.train, data.consumer.soci)

# creat df of consumer LD coords
datPred2.soci <- data.frame(ID = data.consumer.soci$ID,
                            Data = data.consumer.soci$data,
                            Site= data.consumer.soci$site,
                            Sample = as.factor(data.consumer.soci$group1),
                            Group=data.consumer.soci$group2,
                            consumer.pred.soci$x,
                            consumer.pred.soci$class)

datPred2.soci <- datPred2.soci %>%  dplyr::rename("class" = "consumer.pred.soci.class") 

#write.csv(datPred2.soci, "SOCI_LDA.csv")

###----------------------------------------------------####
### soci -> PLOT ---------------------------------     ####
###----------------------------------------------------####

####--------------------------------------------#####
#### perManova -> test differences bn time periods
####--------------------------------------------#####

#test time periods - LD coords
soci.perm <- datPred2.soci %>% select(LD1, LD2)
time<-datPred2.soci$Sample
adonis2(soci.perm ~ time, method="euclidean",perm=9999) # p < 0.001***

######################################################################################

SOCI_LDA = rbind(datPred, datPred2.soci) #bind producer and consumer data

## plot
plot4 = ggplot(SOCI_LDA, aes(x=LD1, y=LD2))

c=plot4 + geom_point(aes(colour = Sample, size= Group, alpha = Group), stroke=2)+
  geom_path(data=source_ell,aes(x=x,y=y,colour=group), size=.75,linetype=2, alpha=.75) +
  #geom_path(data=consumer_ell.soci,aes(x=x, y=y,colour=group),size=1,linetype=2) +
  theme(legend.title = element_blank()) + theme_classic() + 
  labs(x="Linear Discriminant 1 (81.2%)", y="Linear Discriminant 2 (18.8%)") +
  theme(axis.text=element_text(size=14, color='black'),axis.title=element_text(size=14)) +
  theme(axis.title.y = element_blank()) + theme(axis.title.x = element_text(vjust=-2))+
  #geom_text(label = rownames(SOCI_LDA)) +
  theme(plot.margin=unit(c(.5,.5,.5,.5),"cm"))+
  theme(legend.key.size = unit(1.5, 'lines')) +
  scale_color_manual(values = c("#805D3A", "#C69F78", "#92D050", "#0077BB", "#DC5665"))+
  scale_alpha_manual(values = c(.8, .5)) + scale_size_manual(values = c(3, 2)) +  guides(shape = FALSE) +
  theme(legend.position='none') #+ geom_text(x=-5.5, y=-4, label="p ≤ 0.01**", size=3.5, check_overlap = T)


### combine figures
fig1a = ggarrange(a,b,c,nrow = 1, ncol = 3)

fig1a

##############################################################
## all consumers ---------------------------------------- ####
##############################################################

# predict consumers based on ess
consumer.pred <- predict(data.train, data.consumer)

# creat df of consumer LD coords
datPred2 <- data.frame(ID = data.consumer$ID,
                       Data = data.consumer$data,
                       Site= data.consumer$site,
                       Sample = as.factor(data.consumer$group1),
                       Group=data.consumer$group2,
                       consumer.pred$x,
                       consumer.pred$class)

datPred2 <- datPred2%>%  dplyr::rename("class" = "consumer.pred.class") 

All_LDA = rbind(datPred, datPred2)

write.csv(All_LDA, "ALL_smammals_LDA_suess.csv", row.names = F)

#############################################################################################################
#############################################################################################################
##  SIMMR mixing models 
#############################################################################################################
#############################################################################################################

#rm(list=ls(all=TRUE)) 

library(simmr)
library(dplyr)
library(tidyverse)

## LDA coordinates --------------------------------------------------------------------------------------------- ####

lda.mix <- read.csv("ALL_smammals_LDA_suess.csv") %>% filter(Group == "consumer") %>% 
  filter(Sample %in% c("MIOE_1990", "MIOE_2021", "MYRU_1990", "MYRU_2021", "SOCI_1990", "SOCI_2021"))

## SOURCES: 

lda.source <-read.csv("ALL_smammals_LDA_suess.csv") %>% filter(Group == "source") %>% select(Sample, LD1, LD2) %>% 
  group_by(Sample) %>% summarise_all(list(mean=mean, sd=sd)) %>% rename(source=Sample)

#################################################################################################
### simmr mixing models - LDA coords
#################################################################################################

lda = simmr_load(mixtures = as.matrix(lda.mix[, 6:7]),
                 source_names = lda.source$source,
                 source_means = as.matrix(lda.source[,2:3]),
                 source_sds = as.matrix(lda.source[,4:5]),
                 group = as.factor(paste('Year', lda.mix$Sample)))

lda_out<-simmr_mcmc(lda, mcmc_control = list(iter = 100000, burn = 5000, thin = 10, n.chain = 4))

plot(lda)
summary(lda_out, type = "diagnostics") #good
plot(lda_out, type = "matrix")

## Stats and plots
summary(lda_out, group=1:6, type = "statistics")
lda_quant <- summary(lda_out, group=1:6, type = "quantiles")
#plot(lda_out, group=1:6, type="density")
#plot(lda_out, group=1:6, type="boxplot")
compare_groups(lda_out, group=1:6, source_name = "bacteria")
compare_groups(lda_out, group=1:6, source_name = "fungi")
compare_groups(lda_out, group=1:6, source_name = "plant")


#Posterior summary
#MIOE_1990
mioe_1990 <- as.data.frame(lda_out$output$`Year MIOE_1990`$BUGSoutput$sims.matrix)
mioe_1990$brown <- mioe_1990$bacteria + mioe_1990$fungi
mioe_1990 <- gather(mioe_1990 ,"source", "prop", 2:4,7) %>% #convert to long form
  mutate(Year = "MIOE_1990") %>% select(source, prop, Year)

#MIOE_2021
mioe_2021 <- as.data.frame(lda_out$output$`Year MIOE_2021`$BUGSoutput$sims.matrix) 
mioe_2021$brown <- mioe_2021$bacteria + mioe_2021$fungi
mioe_2021 <- gather(mioe_2021 ,"source", "prop", 2:4,7) %>% #convert to long form
  mutate(Year = "MIOE_2021") %>% select(source, prop, Year)

#MYRU_1990
myru_1990 <- as.data.frame(lda_out$output$`Year MYRU_1990`$BUGSoutput$sims.matrix)
myru_1990$brown <- myru_1990$bacteria + myru_1990$fungi
myru_1990 <- gather(myru_1990 ,"source", "prop", 2:4, 7) %>% #convert to long form
  mutate(Year = "MYRU_1990") %>% select(source, prop, Year)

#MYRU_2021
myru_2021 <- as.data.frame(lda_out$output$`Year MYRU_2021`$BUGSoutput$sims.matrix)
myru_2021$brown <- myru_2021$bacteria + myru_2021$fungi
myru_2021 <- gather(myru_2021 ,"source", "prop", 2:4,7) %>% #convert to long form
  mutate(Year = "MYRU_2021") %>% select(source, prop, Year)

#SOCI_1990
soci_1990 <- as.data.frame(lda_out$output$`Year SOCI_1990`$BUGSoutput$sims.matrix)
soci_1990$brown <- soci_1990$bacteria + soci_1990$fungi
soci_1990 <- gather(soci_1990 ,"source", "prop", 2:4,7) %>% #convert to long form
  mutate(Year = "SOCI_1990") %>% select(source, prop, Year)

#SOCI_2021
soci_2021 <- as.data.frame(lda_out$output$`Year SOCI_2021`$BUGSoutput$sims.matrix)
soci_2021$brown <- soci_2021$bacteria + soci_2021$fungi
soci_2021 <- gather(soci_2021 ,"source", "prop", 2:4,7) %>% #convert to long form
  mutate(Year = "SOCI_2021") %>% select(source, prop, Year)

post <- rbind(mioe_1990, mioe_2021,myru_1990, myru_2021, soci_1990, soci_2021)

#separate groups by year/species
post <- post %>% separate(Year, c("species", "year"))

#means
means=post %>%
  group_by(species, year, source) %>%
  dplyr::summarize(mean = mean(prop), sd= sd(prop))

means

#write.csv(means, "LDA_props_STATSforCcycle.csv")

#quantiles
df=lda_quant$quantiles %>%
  map(~.x[2:4,1:5 ]) %>% as.data.frame() %>% rownames_to_column() %>%
  pivot_longer(cols = 2:31) %>% rename("source" = "rowname") %>%
  separate(name, c("group", "quantile"), sep = "\\.", extra = "merge") %>% 
  #filter(quantile %in% c("2.5.", "50.", "97.5.")) %>% 
  mutate(group=recode(group, "group_1"="MIOE_1990", "group_2"="MIOE_2021", "group_3"="MYRU_1990",
                      "group_4"="MYRU_2021", "group_5"="SOCI_1990", "group_6"="SOCI_2021")) %>%
  mutate(quantile=recode(quantile, "2.5." = "l95", "50."="med", "97.5."="u95")) %>%
  separate(group, c("species", "year")) %>% spread(quantile, value)
  
#quantiles plot - median + 95% CI
prop.a = df%>% filter(species == "MIOE") %>%
  ggplot(aes(x=source, y=med, color=year)) + 
  geom_linerange(aes(ymin = l95, ymax = u95, color=year), position = position_dodge2(.75), lwd=.75, alpha = .5) +
  geom_point(aes(fill=year),  size = 3, shape=21, position = position_dodge(width=.75)) +
  theme(legend.title = element_blank()) + theme_classic() + 
  labs(y="Proportion of Carbon", x="Carbon Source") + ylim(0,1) +
  theme(axis.text=element_text(size=12, color='black'),axis.title=element_text(size=14)) +
  theme(axis.title.x = element_text(vjust=-2), axis.title.y = element_text(vjust=2.5)) +
  scale_x_discrete(labels=c("bacteria" = "Bacteria", "fungi" = "Fungi", "plant" = "Plant")) +
  theme(plot.margin=unit(c(.5,.5,.5,.5),"cm"))+
  theme(legend.key.size = unit(1.5, 'lines')) +
  scale_color_manual(values = c("#0077BB", "#DC5665")) +
  scale_fill_manual(values = c("#0077BB", "#DC5665")) + 
  theme(legend.position = "none")
  
prop.b = df%>% filter(species == "MYRU") %>%
  ggplot(aes(x=source, y=med, color=year)) + 
  geom_linerange(aes(ymin = l95, ymax = u95, color=year), position = position_dodge2(.75), lwd=.75, alpha = .5) +
  geom_point(aes(fill=year),  size = 3, shape=21, position = position_dodge(width=.75)) +
  theme(legend.title = element_blank()) + theme_classic() + 
  labs(y="Proportion of Energy", x="Carbon Source") + ylim(0,1) +
  theme(axis.text=element_text(size=12, color='black'),axis.title=element_text(size=14)) +
  theme(axis.title.x = element_text(vjust=-2), axis.title.y = element_blank()) +
  scale_x_discrete(labels=c("bacteria" = "Bacteria", "fungi" = "Fungi", "plant" = "Plant")) +
  theme(plot.margin=unit(c(.5,.5,.5,.5),"cm"))+
  theme(legend.key.size = unit(1.5, 'lines')) +
  scale_color_manual(values = c("#0077BB", "#DC5665")) +
  scale_fill_manual(values = c("#0077BB", "#DC5665")) + 
  theme(legend.position = "none")

prop.c = df%>% filter(species == "SOCI") %>%
  ggplot(aes(x=source, y=med, color=year)) + 
  geom_linerange(aes(ymin = l95, ymax = u95, color=year), position = position_dodge2(.75), lwd=.75, alpha = .5) +
  geom_point(aes(fill=year),  size = 3, shape=21, position = position_dodge(width=.75)) +
  theme(legend.title = element_blank()) + theme_classic() + 
  labs(y="Proportion of Energy", x="Carbon Source") + ylim(0,1) +
  theme(axis.text=element_text(size=12, color='black'),axis.title=element_text(size=14)) +
  theme(axis.title.x = element_text(vjust=-2), axis.title.y = element_blank()) +
  scale_x_discrete(labels=c("bacteria" = "Bacteria", "fungi" = "Fungi", "plant" = "Plant")) +
  theme(plot.margin=unit(c(.5,.5,.5,.5),"cm"))+
  theme(legend.key.size = unit(1.5, 'lines')) +
  scale_color_manual(values = c("#0077BB", "#DC5665")) +
  scale_fill_manual(values = c("#0077BB", "#DC5665")) + 
  theme(legend.position = "none")

fig1b = ggarrange(prop.a, prop.b, prop.c, ncol = 3, nrow = 1)
fig1b

Fig1 = ggarrange(fig1a, fig1b, ncol = 1, nrow = 2)
Fig1

#################################################################################################
### t-test of distributions
#################################################################################################

#create df to populate with values
p <- data.frame(test=c("mioe.bact", "mioe.fungi", "mioe.plant",
                             "myru.bact", "myru.fungi", "myru.plant",
                             "soci.bact", "soci.fungi", "soci.plant"), pval=c(NA))

############################
## MIOE comps
############################

#import posteriors, define distributions for each prey/site
mioe.B1=post %>% filter(source == "bacteria", species == "MIOE", year == "1990") %>% select(prop)
mioe.B2=post %>% filter(source == "bacteria", species == "MIOE", year == "2021") %>% select(prop)
mioe.F1=post %>% filter(source == "fungi", species == "MIOE", year == "1990") %>% select(prop)
mioe.F2=post %>% filter(source == "fungi", species == "MIOE", year == "2021") %>% select(prop)
mioe.P1=post %>% filter(source == "plant", species == "MIOE", year == "1990") %>% select(prop)
mioe.P2=post %>% filter(source == "plant", species == "MIOE", year == "2021") %>% select(prop)

#define new distributions "Y" and "Z"

# bacteria ---------------------------------------------------------------- ####
y.bacteria.mioe <- mioe.B1-mioe.B2
plot(density(y.bacteria.mioe$prop, from=-1, to=1), lwd=2) #plot

z.bacteria.mioe <- mioe.B2-mioe.B1
lines(density(z.bacteria.mioe$prop), type="l" ,lwd=2) #add to plot
abline(v=0, col='grey', lty=2, lwd=2) #mean line

# manual "t-test"
p.bact1.mioe = 1-length(which(y.bacteria.mioe$prop>0))/length(y.bacteria.mioe$prop) +
  length(which(z.bacteria.mioe$prop>0))/length(z.bacteria.mioe$prop)

p.bact2.mioe = length(which(y.bacteria.mioe$prop>0))/length(y.bacteria.mioe$prop) +
  1-length(which(z.bacteria.mioe$prop>0))/length(z.bacteria.mioe$prop)

#p-value -> #p = .4093
p[1,2]<- if(p.bact1.mioe < 1){ 
  print(p.bact1.mioe)
} else {
  print(p.bact2.mioe)
}

# fungi ---------------------------------------------------------------- ####
y.fungi.mioe <- mioe.F1-mioe.F2
plot(density(y.fungi.mioe$prop, from=-1, to=1), lwd=2) #plot

z.fungi.mioe <- mioe.F2-mioe.F1
lines(density(z.fungi.mioe$prop), type="l" ,lwd=2) #add to plot
abline(v=0, col='grey', lty=2, lwd=2) #mean line

# manual "t-test"
p.fun1.mioe = 1-length(which(y.fungi.mioe$prop>0))/length(y.fungi.mioe$prop) +
  length(which(z.fungi.mioe$prop>0))/length(z.fungi.mioe$prop)

p.fun2.mioe = length(which(y.fungi.mioe$prop>0))/length(y.fungi.mioe$prop) +
  1-length(which(z.fungi.mioe$prop>0))/length(z.fungi.mioe$prop)

#p-value = 0.277
p[2,2]<-if(p.fun1.mioe < 1){ 
  print(p.fun1.mioe)
} else {
  print(p.fun2.mioe)
}

# plant ---------------------------------------------------------------- ####
y.plant.mioe <- mioe.P1-mioe.P2
plot(density(y.plant.mioe$prop, from=-1, to=1), lwd=2) #plot

z.plant.mioe <- mioe.P2-mioe.P1
lines(density(z.plant.mioe$prop), type="l" ,lwd=2) #add to plot
abline(v=0, col='grey', lty=2, lwd=2) #mean line

# manual "t-test"
p.plant1.mioe = 1-length(which(y.plant.mioe$prop>0))/length(y.plant.mioe$prop) +
  length(which(z.plant.mioe$prop>0))/length(z.plant.mioe$prop)

p.plant2.mioe = length(which(y.plant.mioe$prop>0))/length(y.plant.mioe$prop) +
  1-length(which(z.plant.mioe$prop>0))/length(z.plant.mioe$prop)

#p-value
p[3,2]<-if(p.plant1.mioe < 1){ 
  print(p.plant1.mioe)
} else {
  print(p.plant2.mioe)
}

############################
## MYRU comps
############################

#import posteriors, define distributions for each prey/site
myru.B1=post %>% filter(source == "bacteria", species == "MYRU", year == "1990") %>% select(prop)
myru.B2=post %>% filter(source == "bacteria", species == "MYRU", year == "2021") %>% select(prop)
myru.F1=post %>% filter(source == "fungi", species == "MYRU", year == "1990") %>% select(prop)
myru.F2=post %>% filter(source == "fungi", species == "MYRU", year == "2021") %>% select(prop)
myru.P1=post %>% filter(source == "plant", species == "MYRU", year == "1990") %>% select(prop)
myru.P2=post %>% filter(source == "plant", species == "MYRU", year == "2021") %>% select(prop)

#define new distributions "Y" and "Z"

# bacteria ---------------------------------------------------------------- ####
y.bacteria.myru <- myru.B1-myru.B2
plot(density(y.bacteria.myru$prop, from=-1, to=1), lwd=2) #plot

z.bacteria.myru <- myru.B2-myru.B1
lines(density(z.bacteria.myru$prop), type="l" ,lwd=2) #add to plot
abline(v=0, col='grey', lty=2, lwd=2) #mean line

# manual "t-test"
p.bact1.myru = 1-length(which(y.bacteria.myru$prop>0))/length(y.bacteria.myru$prop) +
  length(which(z.bacteria.myru$prop>0))/length(z.bacteria.myru$prop)

p.bact2.myru = length(which(y.bacteria.myru$prop>0))/length(y.bacteria.myru$prop) +
  1-length(which(z.bacteria.myru$prop>0))/length(z.bacteria.myru$prop)

#p-value -> #p = .4093
p[4,2]<- if(p.bact1.myru < 1){ 
  print(p.bact1.myru)
} else {
  print(p.bact2.myru)
}

# fungi ---------------------------------------------------------------- ####
y.fungi.myru <- myru.F1-myru.F2
plot(density(y.fungi.myru$prop, from=-1, to=1), lwd=2) #plot

z.fungi.myru <- myru.F2-myru.F1
lines(density(z.fungi.myru$prop), type="l" ,lwd=2) #add to plot
abline(v=0, col='grey', lty=2, lwd=2) #mean line

# manual "t-test"
p.fun1.myru = 1-length(which(y.fungi.myru$prop>0))/length(y.fungi.myru$prop) +
  length(which(z.fungi.myru$prop>0))/length(z.fungi.myru$prop)

p.fun2.myru = length(which(y.fungi.myru$prop>0))/length(y.fungi.myru$prop) +
  1-length(which(z.fungi.myru$prop>0))/length(z.fungi.myru$prop)

#p-value
p[5,2]<-if(p.fun1.myru < 1){ 
  print(p.fun1.myru)
} else {
  print(p.fun2.myru)
}

# plant ---------------------------------------------------------------- ####
y.plant.myru <- myru.P1-myru.P2
plot(density(y.plant.myru$prop, from=-1, to=1), lwd=2) #plot

z.plant.myru <- myru.P2-myru.P1
lines(density(z.plant.myru$prop), type="l" ,lwd=2) #add to plot
abline(v=0, col='grey', lty=2, lwd=2) #mean line

# manual "t-test"
p.plant1.myru = 1-length(which(y.plant.myru$prop>0))/length(y.plant.myru$prop) +
  length(which(z.plant.myru$prop>0))/length(z.plant.myru$prop)

p.plant2.myru = length(which(y.plant.myru$prop>0))/length(y.plant.myru$prop) +
  1-length(which(z.plant.myru$prop>0))/length(z.plant.myru$prop)

#p-value
p[6,2]<-if(p.plant1.myru < 1){ 
  print(p.plant1.myru)
} else {
  print(p.plant2.myru)
}


############################
## SOCI comps
############################

#import posteriors, define distributions for each prey/site
soci.B1=post %>% filter(source == "bacteria", species == "SOCI", year == "1990") %>% select(prop)
soci.B2=post %>% filter(source == "bacteria", species == "SOCI", year == "2021") %>% select(prop)
soci.F1=post %>% filter(source == "fungi", species == "SOCI", year == "1990") %>% select(prop)
soci.F2=post %>% filter(source == "fungi", species == "SOCI", year == "2021") %>% select(prop)
soci.P1=post %>% filter(source == "plant", species == "SOCI", year == "1990") %>% select(prop)
soci.P2=post %>% filter(source == "plant", species == "SOCI", year == "2021") %>% select(prop)

#define new distributions "Y" and "Z"

# bacteria ---------------------------------------------------------------- ####
y.bacteria.soci <- soci.B1-soci.B2
plot(density(y.bacteria.soci$prop, from=-1, to=1), lwd=2) #plot

z.bacteria.soci <- soci.B2-soci.B1
lines(density(z.bacteria.soci$prop), type="l" ,lwd=2) #add to plot
abline(v=0, col='grey', lty=2, lwd=2) #mean line

# manual "t-test"
p.bact1.soci = 1-length(which(y.bacteria.soci$prop>0))/length(y.bacteria.soci$prop) +
  length(which(z.bacteria.soci$prop>0))/length(z.bacteria.soci$prop)

p.bact2.soci = length(which(y.bacteria.soci$prop>0))/length(y.bacteria.soci$prop) +
  1-length(which(z.bacteria.soci$prop>0))/length(z.bacteria.soci$prop)

#p-value -> #p = .4093
p[7,2]<- if(p.bact1.soci < 1){ 
  print(p.bact1.soci)
} else {
  print(p.bact2.soci)
}

# fungi ---------------------------------------------------------------- ####
y.fungi.soci <- soci.F1-soci.F2
plot(density(y.fungi.soci$prop, from=-1, to=1), lwd=2) #plot

z.fungi.soci <- soci.F2-soci.F1
lines(density(z.fungi.soci$prop), type="l" ,lwd=2) #add to plot
abline(v=0, col='grey', lty=2, lwd=2) #mean line

# manual "t-test"
p.fun1.soci = 1-length(which(y.fungi.soci$prop>0))/length(y.fungi.soci$prop) +
  length(which(z.fungi.soci$prop>0))/length(z.fungi.soci$prop)

p.fun2.soci = length(which(y.fungi.soci$prop>0))/length(y.fungi.soci$prop) +
  1-length(which(z.fungi.soci$prop>0))/length(z.fungi.soci$prop)

#p-value
p[8,2]<-if(p.fun1.soci < 1){ 
  print(p.fun1.soci)
} else {
  print(p.fun2.soci)
}

# plant ---------------------------------------------------------------- ####
y.plant.soci <- soci.P1-soci.P2
plot(density(y.plant.soci$prop, from=-1, to=1), lwd=2) #plot

z.plant.soci <- soci.P2-soci.P1
lines(density(z.plant.soci$prop), type="l" ,lwd=2) #add to plot
abline(v=0, col='grey', lty=2, lwd=2) #mean line

# manual "t-test"
p.plant1.soci = 1-length(which(y.plant.soci$prop>0))/length(y.plant.soci$prop) +
  length(which(z.plant.soci$prop>0))/length(z.plant.soci$prop)

p.plant2.soci = length(which(y.plant.soci$prop>0))/length(y.plant.soci$prop) +
  1-length(which(z.plant.soci$prop>0))/length(z.plant.soci$prop)

#p-value
p[9,2]<-if(p.plant1.soci < 1){ 
  print(p.plant1.soci)
} else {
  print(p.plant2.soci)
}

####################################
## adjusted p-value
####################################
library(rstatix)

mix.p <- adjust_pvalue(p, p.col = "pval", method = "BH")
mix.p

#write.csv(mix.p, "PosteriorComparisons_Pvalues.csv")


################################################################################
## C14 dates - plot and t-test btwn times ####
################################################################################

dat14 <- data %>% select(SampleID, group1, group2, species, year, d14C, d14C.SD, d14C_age, d14C_age.SD) %>% drop_na(d14C)
dat14$year <- as.factor(dat14$year)

library(Rmisc)

dat14.err <- group.CI(d14C~year, dat14) %>% rename("d14C" = "d14C.mean")

col <- c("#a1d2f9", "#ffacac", "#118df0", "#ff1212", "#063962", "#790000")

ggplot(data = dat14, aes(x=year, y=d14C)) + geom_boxplot(outlier.shape = NA) +
  geom_point(aes(color=group1), position = position_jitter(0.25), size=5, alpha=0.6) +
  scale_colour_manual(values = col) + theme_classic() + 
  scale_y_continuous(expression(Delta*{}^14*"C (\u2030)"), sec.axis = sec_axis(~ . * 7.41, name = "Age (Years BP)")) +
  theme(plot.margin=unit(c(.5,.5,.5,.5),"cm")) + xlab("Year") +
  theme(axis.text=element_text(size=14, color='black'),axis.title=element_text(size=14)) +
  theme(axis.title.y = element_text(vjust=1.5), axis.title.y.right = element_text(vjust=2.75)) + 
  theme(axis.title.x = element_text(vjust=1.5)) +
  theme(panel.grid.major = element_blank(),panel.grid.minor = element_blank()) +
  theme(legend.position = "none")

t.test(d14C ~ year, data=dat14)

#########################################################################################################  
#########################################################################################################
## Carbon flux - smammals
#########################################################################################################  
#########################################################################################################

#error propagation
library(propagate)

# perbac = % bacteria, perfun = % fungi, perC = %C in tissues, dens = animals/m^2, wt = mean weight of animals
exp <- expression((perbac + perfun)*perC*dens*wt)

#df of proportions
lda_quant$statistics

#percentC from bone
data %>% drop_na(perC) %>% summarise(mean(perC), sd(perC)) %>% as.data.frame()

#density - combined means/sd from Boonstra & Krebs 2012

myDat = ("
n   mean   sd
5  2.38   0.35
11  11.55   1.31
5   14.94   3.42
11  24.31   2.87
") 

myDataFrame <- read.table(textConnection(myDat),header=TRUE)  # conversion to data frame    
myDataFrame                                                  # optional check input

#Algorithm 1: Decomposition of mean and SD to ex (Σx) and exx (Σx2)
nr = nrow(myDataFrame)   # number of rows
ex <- rep(0,nr)          # array to contain Σx
exx <- rep(0,nr)         # array to contain Σx2
tn = 0                   # total n
tx = 0                   # total Σx 
txx = 0                  # total Σx2
for(i in 1:nr)
{
  ex[i] = myDataFrame$n[i] * myDataFrame$mean[i]
  exx[i] = myDataFrame$sd[i]^2 * (myDataFrame$n[i]-1) + ex[i]^2 / myDataFrame$n[i]
  tn = tn + myDataFrame$n[i]
  tx = tx + ex[i]
  txx = txx + exx[i]
}
# concatenate Σx and Σx2 to data frame
myDataFrame$ex <- ex
myDataFrame$exx <- exx
myDataFrame             # show data frame

# Calculate combined values
tMean = tx / tn
tSD = sqrt((txx-tx^2/tn)/(tn-1))
print("Combined n, mean, and SD")
dens <- c(tMean,tSD)
dens <- dens/10000 #meters squared
dens

#mass from BNZ NEON data
path <- "G:/My Drive/Green_Brown/Arctic/Smammals/BNZ_neon/NEON_count-small-mammals/traps"

mass.df <- path %>%  list.files(pattern = "(?i)\\.csv$", full.names = TRUE) %>% 
  set_names(tools::file_path_sans_ext(basename(.))) %>%  map_dfr(read.csv, .id = "colname")

mass.df %>% filter(taxonID == "MYRU", lifeStage == "adult") %>% drop_na(weight) %>% summarise(mean(weight), sd(weight))

#MYRU_1990
perbac <- c(0.1130902, 0.05182895)
perfun <- c(0.1123734, 0.07279421)
perC <- c(0.50626, 0.06603306)
dens <- c(0.0015033125, 0.0008087176)
wt <- c( 21.6444, 5.453932)
  
mr1990 <- cbind(perbac, perfun, perC, dens, wt)

flux.1990=propagate(expr = exp, data = mr1990, type = "stat", 
                  do.sim = TRUE, verbose = TRUE, 
                  nsim = 100000)
flux.1990

#MYRU_2021
perbac <- c(0.04494688, 0.03072920)
perfun <- c(0.51494296, 0.067419867)

mr2021 <- cbind(perbac, perfun, perC, dens, wt)

flux.2021=propagate(expr = exp, data = mr2021, type = "stat", 
                    do.sim = TRUE, verbose = TRUE, 
                    nsim = 100000)

flux.2021

## Total flux change ##########################################

exp <- expression(c.2021-c.1990)
c.2021 <- c(0.0092157165,  0.0059667087)
c.1990 <- c(0.0037186072,  0.0029169834)
dat.c <- cbind(c.2021, c.1990)

flux=propagate(expr = exp, data = dat.c, type = "stat", 
                    do.sim = TRUE, verbose = TRUE, 
                    nsim = 100000)

flux

0.005505302/1000 * 1000000

#########################################################################################################  
#########################################################################################################
#########################################################################################################
#########################################################################################################
### Arcic spiders - Koltz et al. 2018 data, Toolik warming experiment
#########################################################################################################
#########################################################################################################
#########################################################################################################
#########################################################################################################

rm(list=ls(all=TRUE))

# load all AA Data
data <- read.csv("Appendix_S1.csv", strip.white = T, header = T, na.strings = "-")

# Isolate AAess
data.ess<- data %>% 
  dplyr::select(SampleID, group1, group2, species_code, year, site, data, lab, suess_corr, Ile13C, Leu13C, Lys13C, Phe13C, Thr13C, Val13C) %>%
  dplyr::rename("ID"="SampleID", "species" = "species_code", "Ile" = "Ile13C", "Leu" = "Leu13C", "Lys" = "Lys13C", "Phe" = "Phe13C", "Thr" = "Thr13C", "Val" = "Val13C")

data.ess$ID <- as.character(data.ess$ID)

#Suess correction
data.ess$Ile <- data.ess$Ile-data.ess$suess_corr
data.ess$Leu <- data.ess$Leu-data.ess$suess_corr
data.ess$Lys <- data.ess$Lys-data.ess$suess_corr
data.ess$Phe <- data.ess$Phe-data.ess$suess_corr
data.ess$Thr <- data.ess$Thr-data.ess$suess_corr
data.ess$Val <- data.ess$Val-data.ess$suess_corr

###########################################################################################################
###########################################################################################################
### LDA assignment, Consumers -> Bacteria, Fungi, Plant sources                                        ####
###########################################################################################################
###########################################################################################################

###----------------------------------------------------####
### LDA PRODUCERS -> Bacteria, Fungi, Plant sources    ####
###----------------------------------------------------####

#subset 'sources' -> bact/fungi/plant
data.source <- data.ess %>% filter(group2 == "source")

# subset consumers by species
data.consumer <- data.ess %>% filter(group2=="consumer", site == "Arctic")

## Calculating an error rate for our LDA model - using producers
data.lda <- lda(group1 ~ Ile + Leu + Lys + Phe + Thr + Val, data = data.source, CV = TRUE)

# create a table which compares the classifcation of the LDA model to the actual spp
class.prod <- table(data.source$group1, data.lda$class)
class.prod

# total percent of samples correctly classified is the sum of the diagonal of this table
sum(diag(prop.table(class.prod)))

# what % of each species is being correctly classified
diag(prop.table(class.prod, 1))

# create a training lda function from the source data - we will use this to classify the coral hosts
data.train <- lda(group1 ~ Ile + Leu + Lys + Phe + Thr + Val , data = data.source)

#examine coefficents of the discriminants to determine AAs contributing to groups seperation
data.train$scaling

###----------------------------------------------------####
### PLOT1 -> Bacteria, Fungi, Plant sources             ####
###----------------------------------------------------####

# create a dataframe with these LDA coordinates
datPred <- data.frame(ID = data.source$ID,
                      Data = data.source$data,
                      Site= data.source$site,
                      Sample = as.factor(data.source$group1),
                      Group=data.source$group2,
                      predict(data.train)$x,
                      predict(data.train)$class) #create data.frame

datPred <- datPred %>%  dplyr::rename("class" = "predict.data.train..class") 

#function for source ellipses
source_ell <- data.frame() 
for(g in levels(datPred$Sample)){ 
  source_ell <- rbind(source_ell, cbind(as.data.frame(with(datPred[datPred$Sample==g,], 
                                                           ellipse(cor(LD1, LD2), 
                                                                   scale=c(sd(LD1),
                                                                           sd(LD2)), 
                                                                   centre=c(mean(LD1), 
                                                                            mean(LD2))))),
                                        group=g)) } 

#plot sources confidence ellipses
plot1 = ggplot(datPred, aes(x=LD1, y=LD2))

plot1 + geom_point(aes(colour = Sample), size =4, stroke=2, alpha=0.9)+
  geom_path(data=source_ell,aes(x=x,y=y,colour=group),size=1,linetype=2) +
  theme(legend.title = element_blank()) + theme_classic() +
  labs(x="Linear Discriminant 1", y="Linear Discriminant 2") +
  theme(axis.text=element_text(size=18, color='black'),axis.title=element_text(size=20)) +
  theme(axis.title.y = element_text(vjust=2.5)) + theme(axis.title.x = element_text(vjust=-2))+
  theme(legend.position="top") + theme(plot.margin=unit(c(.5,.5,.5,.5),"cm")) +
  scale_colour_manual(values = c("#805D3A", "#C69F78", "#92D050"))

###----------------------------------------------------####
### LDA CONSUMERS -> Bacteria, Fungi, Plant sources    ####
###----------------------------------------------------####

# predict consumers based on ess
consumer.pred <- predict(data.train, data.consumer)

# creat df of consumer LD coords
datPred2 <- data.frame(ID = data.consumer$ID,
                       Data = data.consumer$data,
                       Site= data.consumer$site,
                       Sample = as.factor(data.consumer$group1),
                       Group=data.consumer$group2,
                       consumer.pred$x,
                       consumer.pred$class)

datPred2 <- datPred2 %>%  dplyr::rename("class" = "consumer.pred.class") 

###----------------------------------------------------####
### PLOT2 -> Bacteria, Fungi, Plant sources             ####
###----------------------------------------------------####

Alldata_LDA = rbind(datPred, datPred2) #bind producer and consumer data

## plot
plot2 = ggplot(Alldata_LDA, aes(x=LD1, y=LD2))

fig3a = plot2 + geom_point(aes(colour = Sample, size= Group, alpha = Group), stroke=2) +
  geom_path(data=source_ell,aes(x=x,y=y,colour=group),size=1,linetype=2) +
  #geom_path(data=consumer_ell,aes(x=x, y=y,colour=group),size=1,linetype=2) +
  theme(legend.title = element_blank()) + theme_classic() + 
  labs(x="Linear Discriminant 1 (83.5%)", y="Linear Discriminant 2 (16.5%)") +
  theme(axis.text=element_text(size=12, color='black'),axis.title=element_text(size=14)) +
  theme(axis.title.y = element_text(vjust=2.5)) + theme(axis.title.x = element_text(vjust=-2))+
  #geom_text(label = rownames(MIOE_LDA))+
  theme(plot.margin=unit(c(.5,.5,.5,.5),"cm"))+
  theme(legend.key.size = unit(1.5, 'lines')) +
  scale_color_manual(values = c("#805D3A", "#C69F78", "#92D050", "#0077BB", "#DC5665"))+
  scale_alpha_manual(values = c(.8, .5)) + scale_size_manual(values = c(3, 2)) + 
  theme(legend.position="none")

fig3a

#write.csv(Alldata_LDA, "ARAK_spiders_LDA.csv", row.names = F)
  
####--------------------------------------------#####
#### perManova -> test differences bn time periods
####--------------------------------------------#####

library(vegan)

#test time periods - LD coords
data.perm <- datPred2 %>% select(LD1, LD2)
warm<-datPred2$Sample
adonis2(data.perm ~ warm, method="euclidean",perm=9999) #p=0.0139

#############################################################################################################
#############################################################################################################
##  SIMMR mixing models 
#############################################################################################################
#############################################################################################################

library(simmr)
library(dplyr)
library(tidyverse)

## MIXTURES: 

## LDA coordinates --------------------------------------------------------------------------------------------- ####

lda.mix <- Alldata_LDA %>% filter(Group == "consumer")

## SOURCES: 

lda.source <- Alldata_LDA %>% filter(Group == "source") %>% select(Sample, LD1, LD2) %>% 
  group_by(Sample) %>% summarise_all(list(mean=mean, sd=sd)) %>% rename(source=Sample)

lda.source$source <- as.character(lda.source$source)

#################################################################################################
### simmr mixing models - LDA coords
#################################################################################################

lda = simmr_load(mixtures = as.matrix(lda.mix[, 6:7]),
                 source_names = lda.source$source,
                 source_means = as.matrix(lda.source[,2:3]),
                 source_sds = as.matrix(lda.source[,4:5]),
                 group = as.factor(paste('treatment', lda.mix$Sample)))

plot(lda)

lda_out<-simmr_mcmc(lda, mcmc_control = list(iter = 100000, burn = 5000, thin = 10, n.chain = 4))

## Stats and plots
summary(lda_out, group=1:2, type = "statistics")
lda_quant <- summary(lda_out, group=1:2, type = "quantiles")
#plot(lda_out, group=1:2, type="density")
#plot(lda_out, group=1:2, type="boxplot")
compare_groups(lda_out, group=1:2, source_name = "bacteria")
compare_groups(lda_out, group=1:2, source_name = "fungi")
compare_groups(lda_out, group=1:2, source_name = "plant")

#model checks
summary(lda_out, group=1:2, type="diagnostics")#all good
plot(lda_out, type = "matrix")

## Posterior summary
lda_out$output$`treatment spider_ambient`$BUGSoutput$summary
lda_out$output$`treatment spider_warm`$BUGSoutput$summary

#control
control <- as.data.frame(lda_out$output$`treatment spider_ambient`$BUGSoutput$sims.matrix) 
control <- gather(control ,"source", "prop", 2:4) %>% #convert to long form
  mutate(treatment = "ambient") %>% select(source, prop, treatment)

#warm
treat <- as.data.frame(lda_out$output$`treatment spider_warm`$BUGSoutput$sims.matrix) 
treat <- gather(treat ,"source", "prop", 2:4) %>% #convert to long form
  mutate(treatment = "warm") %>% select(source, prop, treatment)

post <- rbind(control, treat)

#means
means=post %>%
  group_by(source, treatment) %>%
  dplyr::summarize(mean = mean(prop), sd= sd(prop))

#write.csv(means, "SimmR_meanprops_spiders.csv")


#quantiles
df= lda_quant$quantiles %>%
  map(~.x[2:4,1:5 ]) %>% as.data.frame() %>% rownames_to_column() %>%
  pivot_longer(cols = 2:11) %>% rename("source" = "rowname") %>%
  separate(name, c("group", "quantile"), sep = "\\.", extra = "merge") %>% 
  filter(quantile %in% c("2.5.", "50.", "97.5.")) %>% 
  mutate(group=recode(group, "group_1"="Ambient_treatment", "group_2"="Warming_treatment")) %>%
  mutate(quantile=recode(quantile, "2.5." = "l95", "50."="med", "97.5."="u95")) %>%
  spread(quantile, value)

#quantiles plot - median + 95% CI
fig3b = df%>%
  ggplot(aes(x=source, y=med, color=group)) + 
  geom_linerange(aes(ymin = l95, ymax = u95, color=group), position = position_dodge2(.75), lwd=.75, alpha = .5) +
  geom_point(aes(fill=group),  size = 3, shape=21, position = position_dodge(width=.75)) +
  theme(legend.title = element_blank()) + theme_classic() + 
  labs(y="Proportion of Carbon", x="Carbon Source") + ylim(0,1) +
  theme(axis.text=element_text(size=12, color='black'),axis.title=element_text(size=14)) +
  theme(axis.title.x = element_text(vjust=-2), axis.title.y = element_text(vjust=2.5)) +
  scale_x_discrete(labels=c("bacteria" = "Bacteria", "fungi" = "Fungi", "plant" = "Plant")) +
  theme(plot.margin=unit(c(.5,.5,.5,.5),"cm"))+
  theme(legend.key.size = unit(1.5, 'lines')) +
  scale_color_manual(values = c("#0077BB", "#DC5665")) +
  scale_fill_manual(values = c("#0077BB", "#DC5665")) + 
  theme(legend.position = "none")

ggarrange(fig3a, fig3b, nrow = 2, ncol = 1)

#################################################################################################
### t-test of distributions
#################################################################################################

#import posteriors, define distributions for each prey/site
B1=post %>% filter(source == "bacteria", treatment == "ambient") %>% select(prop)
B2=post %>% filter(source == "bacteria", treatment == "warm") %>% select(prop)
F1=post %>% filter(source == "fungi", treatment == "ambient") %>% select(prop)
F2=post %>% filter(source == "fungi", treatment == "warm") %>% select(prop)
P1=post %>% filter(source == "plant", treatment == "ambient") %>% select(prop)
P2=post %>% filter(source == "plant", treatment == "warm") %>% select(prop)

#define new distributions "Y" and "Z"

# bacteria ---------------------------------------------------------------- ####
y.bacteria <- B1-B2
plot(density(y.bacteria$prop, from=-1, to=1), lwd=2) #plot

z.bacteria <- B2-B1
lines(density(z.bacteria$prop), type="l" ,lwd=2) #add to plot
abline(v=0, col='grey', lty=2, lwd=2) #mean line

# manual "t-test"
p.bact1 = 1-length(which(y.bacteria$prop>0))/length(y.bacteria$prop) +
  length(which(z.bacteria$prop>0))/length(z.bacteria$prop)

p.bact2 = length(which(y.bacteria$prop>0))/length(y.bacteria$prop) +
  1-length(which(z.bacteria$prop>0))/length(z.bacteria$prop)

#p-value -> #p = 0.8944
if(p.bact1 < 1){ 
  print(p.bact1)
} else {
  print(p.bact2)
}

# fungi ---------------------------------------------------------------- ####
y.fungi <- F1-F2
plot(density(y.fungi$prop, from=-1, to=1), lwd=2) #plot

z.fungi <- F2-F1
lines(density(z.fungi$prop), type="l" ,lwd=2) #add to plot
abline(v=0, col='grey', lty=2, lwd=2) #mean line

# manual "t-test"
p.fun1 = 1-length(which(y.fungi$prop>0))/length(y.fungi$prop) +
  length(which(z.fungi$prop>0))/length(z.fungi$prop)

p.fun2 = length(which(y.fungi$prop>0))/length(y.fungi$prop) +
  1-length(which(z.fungi$prop>0))/length(z.fungi$prop)

#p-value #.0118
if(p.fun1 < 1){ 
  print(p.fun1)
} else {
  print(p.fun2)
}


# plant ---------------------------------------------------------------- ####
y.plant <- P1-P2
plot(density(y.plant$prop, from=-1, to=1), lwd=2) #plot

z.plant <- P2-P1
lines(density(z.plant$prop), type="l" ,lwd=2) #add to plot
abline(v=0, col='grey', lty=2, lwd=2) #mean line

# manual "t-test"
p.plant1 = 1-length(which(y.plant$prop>0))/length(y.plant$prop) +
  length(which(z.plant$prop>0))/length(z.plant$prop)

p.plant2 = length(which(y.plant$prop>0))/length(y.plant$prop) +
  1-length(which(z.plant$prop>0))/length(z.plant$prop)

#p-value - 0.00652
if(p.plant1 < 1){ 
  print(p.plant1)
} else {
  print(p.plant2)
}

p <- c(0.7851579, 0.01615789, 0.007473684)
p <-as.data.frame(p)
p.adj<- adjust_pvalue(p, p.col = "p", method = "BH")
p.adj

#write.csv(p.adj, "PosteriorComparisons_Pvalues_spiders.csv")

#########################################################################################################  
#########################################################################################################
## Carbon flux - spiders from Koltz et al 2018
#########################################################################################################  
#########################################################################################################

#error propagation
library(propagate)

# perbac = % bacteria, perfun = % fungi, perC = %C in tissues, dens = animals/m^2, wt = mean weight of animals

exp <- expression((perbac + perfun)*perC*dens*wt)

#df of proportions
lda_quant$statistics

#percentC from Spiders
data %>% drop_na(perC) %>% summarise(mean(perC), sd(perC)) %>% as.data.frame()

#control
perbac <- c(0.0599857, 0.034683542)
perfun <- c(0.2592912, 0.08492828)
perC <- c(0.5182, 0.0531) 
dens <- c(1.019, 0) #from Koltz 
wt <- c(0.004279, 0) #from Koltz 

control <- cbind(perbac, perfun, perC, dens, wt)

flux.cont=propagate(expr = exp, data = control, type = "stat", 
                    do.sim = TRUE, verbose = TRUE, 
                    nsim = 100000)
flux.cont

#treatment
perbac <- c( 0.04718878, 0.02701289)
perfun <- c( 0.53340058, 0.06921303)

warmed <- cbind(perbac, perfun, perC, dens, wt)

flux.warm=propagate(expr = exp, data = warmed, type = "stat", 
                    do.sim = TRUE, verbose = TRUE, 
                    nsim = 100000)

flux.warm

#difference scaled up to g/km^2
(0.0013485884 - 0.0007245998) * 1000000 #59821.97 g km-2

#control
0.0007219439 *1000000 / 4360

#warmed
0.0013112656 *1000000 / 4360



